@@ -23,7 +23,7 @@
 
 #include "gl-categorylist.h"
 #include "gl-eventtoolbar.h"
-#include "gl-eventview.h"
+#include "gl-eventviewlist.h"
 #include "gl-util.h"
 #include "gl-window.h"
 
@@ -101,7 +101,6 @@ on_about (GSimpleAction *action,
                            "copyright", "Copyright © 2013–2014 Red Hat, Inc.",
                            "license-type", GTK_LICENSE_GPL_3_0,
                            "logo-icon-name", PACKAGE_TARNAME,
-                           "program-name", PACKAGE_NAME,
                            "version", PACKAGE_VERSION,
                            "website", PACKAGE_URL, NULL);
 }
@@ -165,36 +164,20 @@ static GActionEntry actions[] = {
 static void
 gl_application_startup (GApplication *application)
 {
-    GtkBuilder *builder;
-    GError *error = NULL;
-    GMenuModel *appmenu;
-
     g_action_map_add_action_entries (G_ACTION_MAP (application), actions,
                                      G_N_ELEMENTS (actions), application);
 
     /* Calls gtk_init() with no arguments. */
     G_APPLICATION_CLASS (gl_application_parent_class)->startup (application);
 
-    builder = gtk_builder_new ();
-    gtk_builder_set_translation_domain (builder, GETTEXT_PACKAGE);
-    gtk_builder_add_from_resource (builder, "/org/gnome/Logs/appmenu.ui",
-                                   &error);
-
-    if (error != NULL)
-    {
-        g_error ("Unable to get app menu from resource: %s", error->message);
-    }
-
-    appmenu = G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu"));
-    gtk_application_set_app_menu (GTK_APPLICATION (application), appmenu);
-
-    g_object_unref (builder);
+    /* gtk_init() calls setlocale(), so gettext must be called after that. */
+    g_set_application_name (_(PACKAGE_NAME));
 
     /* Must register custom types before using them from GtkBuilder. */
     gl_window_get_type ();
     gl_category_list_get_type ();
     gl_event_toolbar_get_type ();
-    gl_event_view_get_type ();
+    gl_event_view_list_get_type ();
 }
 
 static void
